function [beta_rad,beta_grad]= imaging_RDA(specUpM,DistAxis,dopAxis,I) 



[RadarP]= Radar_Parm ;       % Radar parameter 
sweepBwd = RadarP.Bandbreite; % Bandwidth
fCenter = RadarP.CFrequenz; % Center freq
ipolN = RadarP.inpol; % FFT points
fTast = RadarP.abtastfrequenz; % Sample freq
sweepDur = RadarP.updauer; % Period
fC = RadarP.C; % 3e8
fLambda = fC / fCenter;
a = 0.014; % m



[pos_max,nro_max,int_max]= max_matrix(specUpM); 
if nro_max == 0
    delta_phase = 0;
    r_meas = 0;
end

specUpM_angle = angle(specUpM);
for i=1:nro_max
    delta_phase(i) = specUpM_angle(pos_max(i,1),pos_max(i,2));
    r_meas(i) = DistAxis (pos_max(i,2));
end

beta_rad = (1)*asin((delta_phase*fLambda)/(2*pi*a));
beta_grad = (180*beta_rad)/pi;

% limit (beta_rad must be less than limit to indicate a good value of beta)
beta_rad_limit = asin(fLambda/(2*a));
beta_grad_limit = (180*beta_rad_limit)/pi
x = 0:0.01:30;
limit_line_p = round_n(x .* (cos(beta_rad_limit+(pi/2))/sin(beta_rad_limit+(pi/2))),2);
limit_line_m = round_n(x .* (cos(-beta_rad_limit+(pi/2))/sin(-beta_rad_limit+(pi/2))),2);


    figure(7),close figure 7

cmap=flipud(colormap('Autumn'));
maxint=max(int_max);
color = round(64.*(int_max)/maxint); % colormap is composed by 64 colors

Dpoints = 3000;
az1=zeros(Dpoints,Dpoints);
for d=1:nro_max
       
    xm(d) = round_n(r_meas(d)  .* sin(beta_rad(d)),2);
    ym(d) = round_n(r_meas(d)  .* cos(beta_rad(d)),2);
    
    %%%%%%%%% 3D coordinates
    x3d (d) = xm(d)*Dpoints/2/15;
    y3d (d) = ym(d)*Dpoints/30;
    
    intnorm=log10(Dpoints*int_max(d));
    intnorm=intnorm/log10(Dpoints*maxint);
    intham=round(50);
    az1(round(x3d(d))-intham+(Dpoints/2):round(x3d(d))+intham+(Dpoints/2),y3d(d)...
        -intham:y3d(d)+intham)=intnorm.*(hamming((2*intham)+1)*hamming((2*intham)+1)');
    %%%%%%%%%%%%%%%%%%%%%%%%

    figure(7),
    title('Range in m; Angle in ; Speed in m/s'),
    range='  R=';
    ran=num2str(round_n(r_meas(d),2));
    angl='; A=';
    ang=num2str(round_n(beta_grad(d),0));
    speed='; Sp=';
    spe=num2str(round_n(dopAxis(pos_max(d,1)),3));
    a=strcat(range,ran,angl,ang,speed,spe);
    text(xm(d),ym(d),texlabel(a),'BackgroundColor',[.9 .9 .7]),
    hold on
    
    grosse = 5.*(int_max(d))/max(int_max);
    figure(7),
    plot(xm(d),ym(d),'^','LineWidth',grosse,...
        'MarkerEdgeColor',[cmap(color(d),1) cmap(color(d),2) cmap(color(d),3)],...
        'MarkerFaceColor',[cmap(color(d),1) cmap(color(d),2) cmap(color(d),3)]),hold on
    colormap(cmap)
    hcb=colorbar('YTickLabel',...
         {'20%','30%','45%','65%','75%','90%'});
     set(hcb,'YTickMode','manual');
     
end


plot(0,0),xlabel ('x / m'),ylabel('y / m'),hold on,
plot(limit_line_p,x,'--k'),hold on
plot(limit_line_m,x,'--k');

figure(8),polar(beta_rad,r_meas,'bs'),title('Polar scheme');
 
meas_results.I = I;
meas_results.range = round_n(r_meas,2);
meas_results.angle_deg = round_n(beta_grad,0);
meas_results.angle_rad = beta_rad;
meas_results.angle_rad_limit = beta_rad_limit

% 3D
% x
ax1=linspace(-15,15,Dpoints);
% % y
ay1=linspace(0,30,Dpoints)';
[ay11,ax11]=meshgrid(ay1,ax1);
colormap(flipud(colormap('autumn')));
mesh(ay11,ax11,az1);
xlabel('y in m'),ylabel('x in m'),zlabel('amplitude');
colormap(cmap)
    hcb=colorbar('YTickLabel',...
        {'10%','20%','30%','40%','50%','60%','70%','80%','90%'});
     set(hcb,'YTickMode','manual');

for d=1:nro_max
    grosse = 5.*(int_max(d))/max(int_max);
     % 3D plot
     figure(11),plot3(ym(d),xm(d),round_n(dopAxis(pos_max(d,1)),3),'s','LineWidth',grosse, ...
     'MarkerEdgeColor',[cmap(color(d),1) cmap(color(d),2) cmap(color(d),3)], ...
        'MarkerFaceColor',[cmap(color(d),1) cmap(color(d),2) cmap(color(d),3)]),hold on
    colormap(cmap);
     xlabel('y in m'),ylabel('x in m'),zlabel('speed in m/s');
     axis([0 30 -15 15 -0.045 0.045]);
     grid on;
     hcb=colorbar('YTickLabel',...
         {'20%','30%','45%','65%','75%','90%'});
     set(hcb,'YTickMode','manual');
end
     







